==> org.eclipse.riena.ui.workarea.source_2.0.0.v20100615_2_0_0.jar: org/eclipse/riena/internal/ui/workarea/registry/ExplicitWorkareaDefinitionRegistry.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.ui.workarea.registry;

import org.eclipse.riena.navigation.INavigationNode;
import org.eclipse.riena.ui.workarea.IWorkareaDefinition;
import org.eclipse.riena.ui.workarea.spi.AbstractWorkareaDefinitionRegistry;

final class ExplicitWorkareaDefinitionRegistry extends AbstractWorkareaDefinitionRegistry {

	private static final ExplicitWorkareaDefinitionRegistry INSTANCE = new ExplicitWorkareaDefinitionRegistry();

	static ExplicitWorkareaDefinitionRegistry getInstance() {
		return INSTANCE;
	}

	private ExplicitWorkareaDefinitionRegistry() {
	}

	@Override
	public IWorkareaDefinition register(Object id, IWorkareaDefinition definition) {

		if (id instanceof INavigationNode<?>) {
			return registerDefinition((INavigationNode<?>) id, definition);
		} else {
			return super.register(id, definition);
		}
	}

	private IWorkareaDefinition registerDefinition(INavigationNode<?> node, IWorkareaDefinition definition) {

		// this may be specific - register with submodule
		workareas.put(node, definition);

		if (node.getNodeId() != null && node.getNodeId().getTypeId() != null) {
			internalRegister(node.getNodeId().getTypeId(), definition);
		}

		return definition;
	}
}

==> org.eclipse.riena.ui.workarea.source_3.0.0.v20110614_3_0_0_0.jar: org/eclipse/riena/internal/ui/workarea/registry/ExplicitWorkareaDefinitionRegistry.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2011 compeople AG and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    compeople AG - initial API and implementation
 *******************************************************************************/
package org.eclipse.riena.internal.ui.workarea.registry;

import org.eclipse.riena.core.singleton.SingletonProvider;
import org.eclipse.riena.navigation.INavigationNode;
import org.eclipse.riena.ui.workarea.IWorkareaDefinition;
import org.eclipse.riena.ui.workarea.spi.AbstractWorkareaDefinitionRegistry;

final class ExplicitWorkareaDefinitionRegistry extends AbstractWorkareaDefinitionRegistry {

	private final static SingletonProvider<ExplicitWorkareaDefinitionRegistry> EWDR = new SingletonProvider<ExplicitWorkareaDefinitionRegistry>(
			ExplicitWorkareaDefinitionRegistry.class);

	static ExplicitWorkareaDefinitionRegistry getInstance() {
		return EWDR.getInstance();
	}

	private ExplicitWorkareaDefinitionRegistry() {
	}

	@Override
	public IWorkareaDefinition register(final Object id, final IWorkareaDefinition definition) {

		if (id instanceof INavigationNode<?>) {
			return registerDefinition((INavigationNode<?>) id, definition);
		} else {
			return super.register(id, definition);
		}
	}

	private IWorkareaDefinition registerDefinition(final INavigationNode<?> node, final IWorkareaDefinition definition) {

		// this may be specific - register with submodule
		workareas.put(node, definition);

		if (node.getNodeId() != null && node.getNodeId().getTypeId() != null) {
			internalRegister(node.getNodeId().getTypeId(), definition);
		}

		return definition;
	}
}
